@@ -21,6 +21,6 @@ test_that("@expect tags produce \\testonly blocks", {
   expect_s3_class(testthat_tag, "roxy_tag_examples")
 
   expect_true(any(grepl("\\\\testonly\\{", testthat_tag$val)))
-  expect_true(any(grepl("testex::testthat_block\\(", testthat_tag$val)))
+  expect_true(any(grepl("testex::testex\\(", testthat_tag$val)))
   expect_true(any(grepl("expect_equals\\(\\., 3\\)", testthat_tag$val)))
 })
